library(testthat)
library(ezplot)
suppressPackageStartupMessages(library(tsibble))

test_check("ezplot")



